package com.ims.eval.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ims.eval.dao.EvaluationNoticeMapper;
import com.ims.eval.entity.EvaluationNotice;
import com.ims.eval.entity.custom.Path;
import com.ims.eval.service.IEvaluationNoticeService;
import com.ims.eval.util.FileConvertUtil;
import com.ims.eval.util.FileUploadUtil;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Date;

/**
 * @author hlf
 * @date 2023/5/17 14:39
 * 文件说明：
 */
@Service
public class EvaluationNoticeServiceImpl extends ServiceImpl<EvaluationNoticeMapper, EvaluationNotice> implements IEvaluationNoticeService {

	@Override
	public IPage<EvaluationNotice> listPage(Integer pageNum, Integer pageSize, String noticeTitle) {
		if (null == pageNum || null == pageSize) {
			throw new RuntimeException("分页参数为空");
		}
		//构造分页构造器
		Page<EvaluationNotice> page = new Page<>(pageNum, pageSize);
		return baseMapper.selectListPage(page, noticeTitle);
	}

	@Override
	public boolean saveOrUpdate(EvaluationNotice evaluationNotice, MultipartFile[] files) throws IOException {
		StringBuilder fileNames = new StringBuilder();
		String str = "";
		if (files.length > 0) {
			for (MultipartFile file : files) {
				// 上传文件路径
				String filePath = Path.getNoticePath();
				// 上传并返回新文件名称
				String fileName = null;
				fileName = FileUploadUtil.upload(filePath, file);
				fileNames.append(fileName).append(",");
			}
			str = fileNames.toString().substring(0, fileNames.toString().length() - 1);
		}
		if ("".equals(evaluationNotice.getId()) || null == evaluationNotice.getId()) {
			evaluationNotice.setCreateTime(new Date());
			if (str.length() > 0) {
				evaluationNotice.setNoticeAnnex(str);
			}
		} else {
			evaluationNotice.setUpdateTime(new Date());
			if (str.length() > 0) {
				EvaluationNotice obj = super.getById(evaluationNotice.getId());
				if (!"".equals(obj.getNoticeAnnex()) && null != obj.getNoticeAnnex()) {
					String noticeAnnex = obj.getNoticeAnnex() + "," + str;
					evaluationNotice.setNoticeAnnex(noticeAnnex);
				}
			}
		}
		return super.saveOrUpdate(evaluationNotice);
	}

	/**
	 * @Description:文件在线预览接口
	 */
	@Override
	public void onlinePreview(String url, HttpServletResponse response) throws Exception {
		/*//获取文件类型
		String[] str = StringUtils.split(url, "\\.");

		if (str.length == 0) {
			throw new Exception("文件格式不正确");
		}
		String suffix = str[str.length - 1];
		if (!suffix.equals("txt") && !suffix.equals("doc") && !suffix.equals("docx") && !suffix.equals("xls") && !suffix.equals("xlsx") && !suffix.equals("ppt") && !suffix.equals("pptx")) {
			throw new Exception("文件格式不支持预览");
		}
		InputStream in = FileConvertUtil.convertNetFile(url, suffix);*/
		InputStream in = null;
		try {
			in = FileConvertUtil.convertLocaleFile(url, "pdf");
			OutputStream outputStream = response.getOutputStream();
			//创建存放文件内容的数组
			byte[] buff = new byte[1024];
			//所读取的内容使用n来接收
			int n;
			//当没有读取完时,继续读取,循环
			while ((n = in.read(buff)) != -1) {
				//将字节数组的数据全部写入到输出流中
				outputStream.write(buff, 0, n);
			}
			//强制将缓存区的数据进行输出
			outputStream.flush();
			//关流
			outputStream.close();
			in.close();
		} catch (Exception e) {
			log.error("错误", e);
		}
	}
}
